#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chokidar_1 = __importDefault(require("chokidar"));
const glob_1 = __importDefault(require("glob"));
const lodash_1 = __importDefault(require("lodash"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const yargs_1 = __importDefault(require("yargs"));
const utils_1 = require("../utils");
function createArgs() {
    const commands = [
        'Create .css.d.ts from CSS modules *.css files.',
        'Usage: $0 [options] <input directory>',
    ];
    // prettier-ignore
    return yargs_1.default
        .usage(commands.join("\n"))
        .example("$0 src/styles", "")
        .example("$0 src -o dist", "")
        .example("$0 -p styles/**/*.icss -w", "")
        .detectLocale(false)
        .demand(["_"])
        .alias("c", "camelCase").describe("c", "Convert CSS class tokens to camelcase").boolean("c")
        .alias("p", "pattern").describe("p", "Glob pattern with css files").default("p", "./src/**/*.css")
        .alias("w", "watch").describe("w", "Watch input directory's css files or pattern").boolean("w")
        .alias("m", "mode").describe("m", "Workmode").choices("m", ["local", "global"]).default("m", "local")
        .alias("h", "help").help("h");
}
// tslint:disable no-console object-literal-sort-keys
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        const yarg = createArgs();
        const { argv } = yarg;
        if (argv.help) {
            yarg.showHelp();
            return;
        }
        const options = {
            mode: argv.mode,
            camelCase: Boolean(argv.camelCase),
            searchDirectory: !lodash_1.default.isEmpty(argv._)
                ? lodash_1.default.first(argv._)
                : argv.pattern
                    ? '.'
                    : undefined,
            filesPattern: argv.pattern,
        };
        if (lodash_1.default.isUndefined(options.searchDirectory)) {
            yarg.showHelp();
            return;
        }
        const filesPattern = path_1.default.join(options.searchDirectory, options.filesPattern || '');
        const createDTSFile = lodash_1.default.unary(utils_1.makeDTSFile(options));
        if (argv.watch) {
            console.log(`Watch ${filesPattern}...`);
            const watcher = chokidar_1.default.watch(filesPattern);
            watcher.on('add', createDTSFile);
            watcher.on('change', createDTSFile);
        }
        else {
            const files = yield util_1.promisify(glob_1.default)(filesPattern);
            lodash_1.default.forEach(files, createDTSFile);
        }
    });
}
// tslint:enable no-console object-literal-sort-keys
main();
//# sourceMappingURL=cli.js.map