"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const chokidar = require("chokidar");
const utils_1 = require("../utils");
class TypedCSSModulesPlugin {
    constructor(options) {
        this.options = _.defaults(options, { filesPattern: './src/**/*.css' });
        this.createDTSFile = _.unary(utils_1.makeDTSFile(this.options));
    }
    apply(compiler) {
        if (this.options.filesPattern === undefined) {
            return;
        }
        const watcher = chokidar.watch(this.options.filesPattern);
        compiler.plugin('compile', () => {
            watcher.on('add', this.createDTSFile);
            watcher.on('change', this.createDTSFile);
        });
        compiler.plugin('done', () => {
            watcher.close();
        });
        return;
    }
}
exports.default = TypedCSSModulesPlugin;
//# sourceMappingURL=webpack-plugin.js.map