"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const chai_1 = require("chai");
require("mocha");
const modules_selector_1 = require("./modules-selector");
describe('getModuleTokens with selector', () => {
    it('local mode', () => {
        // tslint:disable object-literal-sort-keys
        const mapping = {
            '.foo': ['foo'],
            '.foo .bar': ['foo', 'bar'],
            // Shorthand global selector
            ':global .foo .bar': [],
            '.foo :global .bar': ['foo'],
            // Targeted global selector
            ':global(.foo) .bar': ['bar'],
            '.foo:global(.bar)': ['foo'],
            '.foo :global(.bar) .baz': ['foo', 'baz'],
            '.foo:global(.bar) .baz': ['foo', 'baz'],
        };
        // tslint:enable object-literal-sort-keys
        lodash_1.default.forEach(mapping, (matches, selector) => {
            const locals = modules_selector_1.getModuleTokensWithSelector(selector, {
                mode: 'local',
            });
            chai_1.expect(matches).to.eql(locals);
        });
    });
    it('global mode', () => {
        // tslint:disable object-literal-sort-keys
        const mapping = {
            '.foo': [],
            '.foo .bar': [],
            // Shorthand local selector
            ':local .foo :global .bar': ['foo'],
            '.foo :local .bar': ['bar'],
            // Targeted local selector
            ':local(.foo) .bar': ['foo'],
            '.foo:local(.bar)': ['bar'],
        };
        // tslint:enable object-literal-sort-keys
        lodash_1.default.forEach(mapping, (matches, selector) => {
            const locals = modules_selector_1.getModuleTokensWithSelector(selector, {
                mode: 'global',
            });
            chai_1.expect(matches).to.eql(locals);
        });
    });
});
//# sourceMappingURL=modules-selector.spec.js.map